@@ -31,7 +31,7 @@ BEGIN {
     Win32::API::->Import("psapi","BOOL EnumProcessModules(HANDLE  hProcess, HMODULE *lphModule, DWORD   cb, LPDWORD lpcbNeeded)") or die "EnumProcessModules: $^E";  # uncoverable branch true
 }
 
-our $VERSION = '0.007'; # auto-populated from W::M::NPP
+our $VERSION = '0.008'; # auto-populated from W::M::NPP
 
 our @EXPORT_VARS = (@Win32::Mechanize::NotepadPlusPlus::Notepad::Messages::EXPORT);
 
@@ -174,6 +174,8 @@ sub _new
     my @sci_hwnds = @{$self->_enumScintillaHwnds()}[0..1];       # first two are the main editors
     @{$self}{qw/editor1 editor2/} = map Win32::Mechanize::NotepadPlusPlus::Editor->_new($_, $self->{_hwobj}), @sci_hwnds;
 
+    $self->{debugInfo} = $self->_initDebugInfo();
+
     return $self;
 }
 
@@ -1416,17 +1418,89 @@ sub setStatusBar {
     # NPPM_SETSTATUSBAR
 }
 
-# make _getStatusBar private, since it doesn't work (yet)
-#sub _getStatusBar {
-#    # There may be a workaround which could be implemented: for each of the sections, compute the default value...
-#    #   or see dev-zoom-tooltips.py : npp_get_statusbar()
-#    my $self = shift;
-#    my $section = shift;
-#    $section = $STATUSBAR{$section} if exists $STATUSBAR{$section};   # allow name or value
-#    return undef;
-#    #return $self->{_hwobj}->SendMessage_sendStrAsUcs2le( $NPPMSG{NPPM_SETSTATUSBAR} , $section, $text );
-#    # NPPM_GETSTATUSBAR -- Does Not Exist!
-#}
+=item getStatusBar
+
+    my $text = notepad->getStatusBar($statusBarSection);
+
+Gets the text from the selected status bar section.
+
+For C<$statusBarSection>, use one of the L<%STATUSBAR|Win32::Mechanize::NotepadPlusPlus::Notepad::Messages/"%STATUSBAR"> values.
+
+=cut
+
+sub _populateStatusBarHwnd {
+    my ($self) = @_;
+    return $self->{_sbhwobj} if $self->{_sbhwobj};
+    
+    my $sbWnd;
+
+    for my $cWnd ( GetChildWindows($self->hwnd) )
+    {
+        my $c = GetClassName($cWnd);
+        $sbWnd = $cWnd if $c eq  'msctls_statusbar32';
+    }
+
+    return $self->{_sbhwobj} = Win32::Mechanize::NotepadPlusPlus::__hwnd->new( $sbWnd ); # create an object
+}
+
+sub getStatusBar {
+    # NPPM_GETSTATUSBAR -- Does Not Exist! so I have to work around that using Win32 calls
+    my ($self, $section) = @_;
+    $section = $STATUSBAR{$section} if exists $STATUSBAR{$section};   # allow name or value
+    
+    my ($SB_GETTEXTLENGTHW , $SB_GETTEXTW ) = map {0x400 + $_} 12, 13; # WM_USER + offset
+
+    $self->_populateStatusBarHwnd();
+
+    my $retcode = $self->{_sbhwobj}->SendMessage($SB_GETTEXTLENGTHW, $section, 0) & 0x00FF;
+    #printf STDERR "getStatusBar(%d): hwnd=0x%08x msg=0x%04x length=>%d\n", $section, $self->{_sbhwobj}->hwnd, $SB_GETTEXTLENGTHW, $retcode//'<undef>';
+
+    my $retstr = $self->{_sbhwobj}->SendMessage_getUcs2le($SB_GETTEXTW, $section, { trim => $retcode } );
+    #printf STDERR "getStatusBar(%d): hwnd=0x%08x txt='%s'\n", $section, $self->{_sbhwobj}->hwnd, $retstr//'<undef>';
+
+    return $retstr;
+}
+
+=item showDocList
+
+=item isDocListShown
+
+    notepad->showDocList($toShowOrNot);     # show the list if toShowOrNot is true
+    my $shown = notepad->isDocListShown;    # get the status
+
+Sets or gets the status of whether the Document List panel is shown.
+
+I<Note:> Prior to Notepad++ v8.1.3, the Document List panel was previously known as the "Doc Switcher",
+which was often confused with the similarly-named MISC setting "Document Switcher (Ctrl+TAB)".
+Since these methods were added to this module after the panel was renamed in Notepad++, the module
+uses the new name, even if you use it with an older Notepad++.
+
+=cut
+
+sub showDocList {
+    # NPPM_SHOWDOCLIST, wParam=0, lParam=boolean
+    my ($self, $toShowOrNot) = @_;
+    return $self->SendMessage( $NPPMSG{NPPM_SHOWDOCLIST}, 0, $toShowOrNot);
+}
+
+sub isDocListShown {
+    my ($self) = @_;
+    return $self->SendMessage( $NPPMSG{NPPM_ISDOCLISTSHOWN}, 0, 0);
+}
+
+=item docListDisableColumn
+
+    notepad->docListDisableColumn($disableOrNot);   # disables the extension column if disableOrNot is true
+
+Sets whether or not the Document List panel disables (1) or shows (0) the extension in a separate column.
+
+=cut
+
+sub docListDisableColumn {
+    # NPPM_DOCLISTDISABLECOLUMN, wParam=0, lParam=boolean
+    my ($self, $toDisableOrNot) = @_;
+    return $self->SendMessage( $NPPMSG{NPPM_DOCLISTDISABLECOLUMN}, 0, $toDisableOrNot);
+}
 
 =item getLineNumberWidthMode
 
@@ -1665,6 +1739,46 @@ sub runPluginCommand {
     }
 }
 
+=item getShortcutByCmdId
+
+    notepad->getShortcutByCmdId(22000); # returns the shortcut info for the plugin command with ID=22000
+
+Gets the mapped command shortcut for a plugin-menu command.  (Does not work on the other menus.)
+May be called after getting NPPN_READY notification.
+
+Returns:
+Shortcut information as a list (array), where the first three elements are
+Booleans indicating the state of the the Ctrl and Alt and Shift keys, and the
+fourth element is the shortcut key.
+
+=cut
+
+sub getShortcutByCmdId {
+    my ($self, $cmdid) = @_;
+    my ($ctrl, $alt, $shift, $char) = unpack 'cccA' => my $ret = $self->{_hwobj}->SendMessage_getRawString( $NPPMSG{NPPM_GETSHORTCUTBYCMDID} , $cmdid );
+    $char =~ s/([[:cntrl:]])/'\\x' . hex ord $1/ge;
+    #print STDERR "getShortcutByCmdId($cmdid) => '$ret' = ($ctrl, $alt, $shift, $char)\n";
+    return($ctrl, $alt, $shift, $char);
+}
+
+=item removeShortcutByCmdId
+
+    notepad->removeShortcutByCmdId(22000); # clears the shortcut info for the plugin command with ID=22000
+
+Clears the mapped command shortcut for a plugin-menu command.  (Does not work on the other menus.)
+May be called after getting NPPN_READY notification.
+
+Returns:
+
+=cut
+
+sub removeShortcutByCmdId {
+    my ($self, $cmdid) = @_;
+    return $self->{_hwobj}->SendMessage( $NPPMSG{NPPM_REMOVESHORTCUTBYCMDID} , $cmdid );
+}
+
+
+
 =item messageBox
 
     notepad->messageBox($message, $title, $flags);
@@ -1673,10 +1787,16 @@ sub runPluginCommand {
 
 Displays a message box with the given message and title.
 
-    Flags can be 0 for a standard ‘OK’ message box, or a combination of MESSAGEBOXFLAGS. title is “Win32::Mechanize::NotepadPlusPlus” by default, and flags is 0 by default.
+Flags can be 0 for a standard ‘OK’ message box, or a combination of values from the
+L<%WINMSGBOX|Win32::Mechanize::NotepadPlusPlus::Notepad::Messages/%WINMSGBOX> hash.
 
 Returns:
-A RESULTxxxx member of MESSAGEBOXFLAGS as to which button was pressed.
+The value from one of the %WINMSGBOX C<RESULT_*> entries.
+
+Example:
+
+    my $mb = notepad->messageBox('message', 'title', $WINMSGBOX{OKCANCEL});
+    if( $mb == $WINMSGBOX{RETURN_OK} ) { ... } else { ... }
 
 =cut
 
@@ -1874,16 +1994,14 @@ sub getPerlBits {
 
     notepad->getCommandLine();
 
-Gets the command line used to start Notepad++
-
-NOT IMPLEMENTED.  RETURNS C<undef>.  (May be implemented in the future.)
+Gets the command line used to start Notepad++, when using v8.0 or newer.
+On older versions, returns C<undef>.
 
 =cut
 
 sub getCommandLine {
     my $self = shift;
-    # https://github.com/bruderstein/PythonScript/blob/1d9230ffcb2c110918c1c9d36176bcce0a6572b6/PythonScript/src/NotepadPlusWrapper.cpp#L893
-    return undef;
+    return $self->getDebugInfo('Command line');
 }
 
 =item getNppDir
@@ -1971,6 +2089,69 @@ sub getSettingsOnCloudPath {
     return $dir;
 }
 
+=item getDebugInfo
+
+    my $debugInfoHashRef = notepad->getDebugInfo();
+    my $isAdmin = notepad->getDebugInfo('Admin mode');
+    my @vals = notepad->getDebugInfo(@keys);
+
+Parses the contents of the ?-menu's Debug Info dialog box and gives
+you read-only access to an anonymous hash or individual values from
+the information.  If the requested key(s) do not exist, it will return
+C<undef>.  The keys are the lowercase versions of the strings before
+the colons in each line of the Debug Info.  Not all keys are available
+in all instances or versions of Notepad++.
+
+    KEY                     | Description
+    ------------------------+---------------
+    '-APP'                  | Notepad++ version number (first line from Debug Info)
+    'build time'            | The date and time that this version of Notepad++ was built
+    'path'                  | The path to the notepad++.exe executable
+    'command line'          | Command line arguments for this instance of Notepad++ (v8.x)
+    'admin mode'            | Whether Adminstrator Mode is "ON" or "OFF"
+    'local conf mode'       | Whether config files will be found in the notepad++ folder or not ("ON" or "OFF")
+    'cloud config'          | Indicates if config files are in the cloud folder (lists folder) or not ("OFF") (v8.x)
+    'os name'               | Name of the Windows OS used
+    'os version'            | Version of the Windows OS used
+    'os build'              | Build of the Windows OS used
+    'current ansi codepage' | Codepage number active for "ANSI" files
+    'plugins'               | Space-separated list of plugin DLLs loaded
+
+=cut
+
+sub _initDebugInfo {
+    my ($self) = @_;
+    my %DebugInfo;
+
+    $self->menuCommand($NPPIDM{IDM_DEBUGINFO});
+
+    my $hWnd = WaitWindowLike(0, 'Debug Info', undef, undef, undef, 2); #wait up to 2 seconds for the DebugInfo
+    # grab the debugInfo
+
+    my $debugInfo;
+    for my $c (GetChildWindows($hWnd)) {
+        $debugInfo = WMGetText($c) if GetClassName($c) eq 'Edit';
+    }
+    # done with dialog
+    SetForegroundWindow($hWnd);
+    SendKeys('{PAUSE 250}{ESC}', 250);
+
+    for ( split /\R/, $debugInfo ) {
+        $DebugInfo{-APP} = $_, next unless exists $DebugInfo{-APP};
+        next unless /^(.*?)\s*:\s*(.*)\s*$/;
+        $DebugInfo{lc $1} = $2;
+    }
+
+    return \%DebugInfo;
+}
+
+sub getDebugInfo {
+    my ($self, @keys) = @_;
+    return $self->{debugInfo} unless @keys;
+    return @{ $self->{debugInfo} }{map {$_ eq '-APP' ? '-APP' : lc $_ } @keys};
+}
+
+
 =back
 
 =for comment /end of Meta Information
